"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@openapi-generator-plus/core");
const change_case_1 = require("change-case");
/** Returns the string converted to a string that is safe as an identifier in most languages */
function identifierSafe(value) {
    /* Remove invalid leading characters */
    value = value.replace(/^[^a-zA-Z_]*/, '');
    /* Convert any illegal characters to underscores */
    value = value.replace(/[^a-zA-Z0-9_]/g, '_');
    return value;
}
/**
 * Camel case and capitalize suitable for a class name. Doesn't change existing
 * capitalization in the value.
 * e.g. "FAQSection" remains "FAQSection", and "faqSection" will become "FaqSection"
 * @param value string to be turned into a class name
 */
function classCamelCase(value) {
    return core_1.pascalCase(identifierSafe(value));
}
exports.classCamelCase = classCamelCase;
function identifierCamelCase(value) {
    return core_1.camelCase(identifierSafe(value));
}
exports.identifierCamelCase = identifierCamelCase;
function javaLikeGenerator() {
    return {
        toClassName: (name) => {
            return classCamelCase(name);
        },
        toIdentifier: (name) => {
            return identifierCamelCase(name);
        },
        toConstantName: (name) => {
            return change_case_1.constantCase(name);
        },
        toEnumName: (name) => {
            return classCamelCase(name) + 'Enum';
        },
    };
}
exports.javaLikeGenerator = javaLikeGenerator;
